==> xstate-3.3.3.tgz: package/test/data.test.ts <==
import { assert } from 'chai';
import { Machine } from '../src/index';

describe('state data', () => {
  const pedestrianStates = {
    initial: 'walk',
    states: {
      walk: {
        data: { walkData: 'walk data' },
        on: {
          PED_COUNTDOWN: 'wait'
        },
        onEntry: 'enter_walk',
        onExit: 'exit_walk'
      },
      wait: {
        data: { waitData: 'wait data' },
        on: {
          PED_COUNTDOWN: 'stop'
        },
        onEntry: 'enter_wait',
        onExit: 'exit_wait'
      },
      stop: {
        data: { stopData: 'stop data' },
        onEntry: 'enter_stop',
        onExit: 'exit_stop'
      }
    }
  };

  const lightMachine = Machine({
    key: 'light',
    initial: 'green',
    states: {
      green: {
        data: ['green', 'array', 'data'],
        on: {
          TIMER: 'yellow',
          POWER_OUTAGE: 'red',
          NOTHING: 'green'
        },
        onEntry: 'enter_green',
        onExit: 'exit_green'
      },
      yellow: {
        data: { yellowData: 'yellow data' },
        on: {
          TIMER: 'red',
          POWER_OUTAGE: 'red'
        },
        onEntry: 'enter_yellow',
        onExit: 'exit_yellow'
      },
      red: {
        data: {
          redData: {
            nested: {
              red: 'data',
              array: [1, 2, 3]
            }
          }
        },
        on: {
          TIMER: 'green',
          POWER_OUTAGE: 'red',
          NOTHING: 'red'
        },
        onEntry: 'enter_red',
        onExit: 'exit_red',
        ...pedestrianStates
      }
    }
  });

  it('states should aggregate data', () => {
    assert.deepEqual(lightMachine.transition('green', 'TIMER').data, {
      'light.yellow': {
        yellowData: 'yellow data'
      }
    });
  });

  it('states should aggregate data (deep)', () => {
    assert.deepEqual(lightMachine.transition('yellow', 'TIMER').data, {
      'light.red': {
        redData: {
          nested: {
            array: [1, 2, 3],
            red: 'data'
          }
        }
      },
      'light.red.walk': {
        walkData: 'walk data'
      }
    });
  });
});

==> xstate-4.0.0-13.tgz: package/test/data.test.ts <==
import { assert } from 'chai';
import { Machine } from '../src/index';

describe('state data', () => {
  const pedestrianStates = {
    initial: 'walk',
    states: {
      walk: {
        data: { walkData: 'walk data' },
        on: {
          PED_COUNTDOWN: 'wait'
        },
        onEntry: 'enter_walk',
        onExit: 'exit_walk'
      },
      wait: {
        data: { waitData: 'wait data' },
        on: {
          PED_COUNTDOWN: 'stop'
        },
        onEntry: 'enter_wait',
        onExit: 'exit_wait'
      },
      stop: {
        data: { stopData: 'stop data' },
        onEntry: 'enter_stop',
        onExit: 'exit_stop'
      }
    }
  };

  const lightMachine = Machine({
    key: 'light',
    initial: 'green',
    states: {
      green: {
        data: ['green', 'array', 'data'],
        on: {
          TIMER: 'yellow',
          POWER_OUTAGE: 'red',
          NOTHING: 'green'
        },
        onEntry: 'enter_green',
        onExit: 'exit_green'
      },
      yellow: {
        data: { yellowData: 'yellow data' },
        on: {
          TIMER: 'red',
          POWER_OUTAGE: 'red'
        },
        onEntry: 'enter_yellow',
        onExit: 'exit_yellow'
      },
      red: {
        data: {
          redData: {
            nested: {
              red: 'data',
              array: [1, 2, 3]
            }
          }
        },
        on: {
          TIMER: 'green',
          POWER_OUTAGE: 'red',
          NOTHING: 'red'
        },
        onEntry: 'enter_red',
        onExit: 'exit_red',
        ...pedestrianStates
      }
    }
  });

  it('states should aggregate data', () => {
    const yellowState = lightMachine.transition('green', 'TIMER');
    assert.deepEqual(yellowState.data, {
      'light.yellow': {
        yellowData: 'yellow data'
      }
    });
    assert.notProperty(yellowState.data, 'light.green');
    assert.notProperty(yellowState.data, 'light');
  });

  it('states should aggregate data (deep)', () => {
    assert.deepEqual(lightMachine.transition('yellow', 'TIMER').data, {
      'light.red': {
        redData: {
          nested: {
            array: [1, 2, 3],
            red: 'data'
          }
        }
      },
      'light.red.walk': {
        walkData: 'walk data'
      }
    });
  });
});
